==> tkvoice-1.3.tar.gz: tkvoice-1.3/TCL/tkviewfax.tcl <==
# tkviewfax.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkviewfax
catch {destroy $w}
toplevel $w
wm title $w "tkVoice View FAX"
wm iconname $w "tkVoice View FAX"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w
set tkVIEWFAX 1

global FAX PAGE PAGET c tkVIEWFAX

# START PROCS Section

proc makexbm {} {
global userhome faxdpi resdpi FAX PAGE
  # Clean out old temp files:
    catch [exec rm $userhome/tkvoice.ps $userhome/tkvoice.ppm \
          $userhome/tkvoice.gif $userhome/tkvoice.tmp $userhome/tkvoice.bmp]
 
  # Convert g3 to PBM to PS
  # This works great for EPSON Stylus 640:
  # g32pbm: is part of mgetty package http://alpha.greenie.net/mgetty/
  # pbmtolps: is part of netpbm package http://sourceforge.net/projects/netpbm/
  #  catch [eval exec g32pbm $FAX.$PAGE | pbmtolps -dpi $faxdpi > $userhome/tkvoice.ps]
  # Convert g3 to PBM to XBM
    catch [eval exec g32pbm -d $resdpi $FAX.$PAGE | pbmtoxbm > $userhome/tkvoice.xbm]
 
  # Convert PS to PPM
  # gs: is part of ghostscript package http://www.cs.wisc.edu/~ghost/
  #  catch [eval exec gs -q -dSAFER -dNOPAUSE -dBATCH \
  #     -sDEVICE=ppm -sOutputFile=$userhome/tkvoice.ppm $userhome/tkvoice.ps]
 
  # Convert PPM to GIF
  # ppmtogif: is part of netpbm package http://sourceforge.net/projects/netpbm/
  #  catch [eval exec ppmtogif $userhome/tkvoice.ppm > $userhome/tkvoice.gif]
}
######################## END proc makexbm #######################

proc onetime {} {
global userhome p c resdpi FAX PAGE PAGET
$c delete item
catch {image delete faximage}
set resdpi 75
makexbm
image create bitmap faximage -file [file join $userhome/tkvoice.xbm] -background white
$c create image 4.4i 5.7i -tags item -image faximage
$p configure -state normal
$p delete 0.0 5.0
$p insert 0.0 $PAGE/$PAGET
$p configure -state disabled
}

proc twotime {} {
global userhome c resdpi FAX PAGE
$c delete item
set resdpi 150
makexbm
image create bitmap faximage -file [file join $userhome/tkvoice.xbm] -background white
$c create image 8.7i 11.4i -tags item -image faximage
}

proc threetime {} {
global userhome c resdpi FAX PAGE
$c delete item
set resdpi 300
makexbm
image create bitmap faximage -file [file join $userhome/tkvoice.xbm] -background white
$c create image 17.4i 22.6i -tags item -image faximage
}

proc nomore {} {
global tkvoicedir tkVoice sof FAX PAGE userhome
uplevel [list source [file join $tkvoicedir/TCL/tkvnomore.tcl]]
}

proc nextpage {} {
global userhome FAX PAGE sof

if {[string range $PAGE 0 0] == "0"} {
set PCNT [string range $PAGE 1 1]
} else {
set PCNT $PAGE
}

set npage [expr $PCNT+1]
if {$npage < 10} {
  set tmp "0"
  append tmp $npage
  set npage $tmp
}

catch { exec ls $FAX.$npage } test
if { $test != "$FAX.$npage" } {
  set sof "0"
  nomore
  } else {
  set PAGE $npage
  makexbm
  onetime
  }
} 

proc prevpage {} {
global userhome FAX PAGE sof

if {[string range $PAGE 0 0] == "0"} {
set PCNT [string range $PAGE 1 1]
} else {
set PCNT $PAGE
}

set ppage [expr $PCNT-1]
if {$ppage < 10} {
  set tmp "0"
  append tmp $ppage
  set ppage $tmp
}

catch { exec ls $FAX.$ppage } test
if { $test != "$FAX.$ppage" } {
  set sof "1"
  nomore
  } else {
  set PAGE $ppage
  makexbm
  onetime
  }
} 

proc printfax {} {
global tkvoicedir userhome FAX PAGE PAGET printcmd printsel faxdpi

uplevel [list source [file join $tkvoicedir/TCL/tkvprintfax.tcl]]
}

# END PROCS Section

######################################################
# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoiceviewfax}
image create photo tkvoiceviewfax -file [file join $tkvoicedir/image/tkvoiceviewfax.gif]

label $w.gif.tkvoiceviewfax -image tkvoiceviewfax -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoiceviewfax -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right

#########################

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.print -text PRINT -command "printfax"
pack $w.buttons.print -side left -expand 1
button $w.buttons.onetime -text "1X" -command "onetime"
pack $w.buttons.onetime -side left -expand 1
button $w.buttons.twotime -text "2X"  -command "twotime"
pack $w.buttons.twotime -side left -expand 1
button $w.buttons.threetime -text "3X"  -command "threetime"
pack $w.buttons.threetime -side left -expand 1
button $w.buttons.prevpage -text "Prev Page" -command "prevpage"
pack $w.buttons.prevpage -side left -expand 1
set p $w.buttons.page
text $p -relief sunken -width 5 -height 1
pack $p -side left
button $w.buttons.nextpage -text "Next Page" -command "nextpage"
pack $w.buttons.nextpage -side left -expand 1
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.cancel -side left -expand 1

frame $w.fax
pack $w.fax -side top -fill both -expand yes

set c $w.fax.c
canvas $c -scrollregion {0i 0i 35i 45.5i} -width 8.8i -height 5.5i \
	-relief groove -borderwidth 2 \
	-xscrollcommand "$w.fax.hscroll set" \
	-yscrollcommand "$w.fax.vscroll set"
scrollbar $w.fax.vscroll -command "$c yview"
scrollbar $w.fax.hscroll -orient horiz -command "$c xview"

grid $c -in $w.fax \
    -row 0 -column 0 -rowspan 1 -columnspan 1 -sticky news
grid $w.fax.vscroll \
    -row 0 -column 1 -rowspan 1 -columnspan 1 -sticky news
grid $w.fax.hscroll \
    -row 1 -column 0 -rowspan 1 -columnspan 1 -sticky news
grid rowconfig    $w.fax 0 -weight 1 -minsize 0
grid columnconfig $w.fax 0 -weight 1 -minsize 0

onetime

==> tkvoice-1.5.tar.gz: tkvoice-1.5/TCL/tkviewfax.tcl <==
# tkviewfax.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkviewfax
catch {destroy $w}
toplevel $w
wm title $w "tkVoice View FAX"
wm iconname $w "tkVoice View FAX"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w
set tkVIEWFAX 1

global FAX PAGE PAGET c tkVIEWFAX

# START PROCS Section

proc makexbm {} {
global userhome faxdpi resdpi FAX PAGE
  # Clean out old temp files:
    catch {exec rm $userhome/tkvoice.ps $userhome/tkvoice.ppm \
          $userhome/tkvoice.gif $userhome/tkvoice.tmp $userhome/tkvoice.bmp}
 
  # Convert g3 to PBM to PS
  # This works great for EPSON Stylus 640:
  # g32pbm: is part of mgetty package http://alpha.greenie.net/mgetty/
  # pbmtolps: is part of netpbm package http://sourceforge.net/projects/netpbm/
  #  catch {eval exec g32pbm $FAX.$PAGE | pbmtolps -dpi $faxdpi > $userhome/tkvoice.ps}
  # Convert g3 to PBM to XBM
    catch {eval exec g32pbm -d $resdpi $FAX.$PAGE | pbmtoxbm > $userhome/tkvoice.xbm}
 
  # Convert PS to PPM
  # gs: is part of ghostscript package http://www.cs.wisc.edu/~ghost/
  #  catch {eval exec gs -q -dSAFER -dNOPAUSE -dBATCH \
  #     -sDEVICE=ppm -sOutputFile=$userhome/tkvoice.ppm $userhome/tkvoice.ps}
 
  # Convert PPM to GIF
  # ppmtogif: is part of netpbm package http://sourceforge.net/projects/netpbm/
  #  catch {eval exec ppmtogif $userhome/tkvoice.ppm > $userhome/tkvoice.gif}
}
######################## END proc makexbm #######################

proc onetime {} {
global userhome p c resdpi FAX PAGE PAGET
$c delete item
catch {image delete faximage}
set resdpi 75
makexbm
image create bitmap faximage -file [file join $userhome/tkvoice.xbm] -background white
$c create image 4.4i 5.7i -tags item -image faximage
$p configure -state normal
$p delete 0.0 5.0
$p insert 0.0 $PAGE/$PAGET
$p configure -state disabled
}

proc twotime {} {
global userhome c resdpi FAX PAGE
$c delete item
set resdpi 150
makexbm
image create bitmap faximage -file [file join $userhome/tkvoice.xbm] -background white
$c create image 8.7i 11.4i -tags item -image faximage
}

proc threetime {} {
global userhome c resdpi FAX PAGE
$c delete item
set resdpi 300
makexbm
image create bitmap faximage -file [file join $userhome/tkvoice.xbm] -background white
$c create image 17.4i 22.6i -tags item -image faximage
}

proc nomore {} {
global tkvoicedir tkVoice sof FAX PAGE userhome
uplevel [list source [file join $tkvoicedir/TCL/tkvnomore.tcl]]
}

proc nextpage {} {
global userhome FAX PAGE sof

if {[string range $PAGE 0 0] == "0"} {
set PCNT [string range $PAGE 1 1]
} else {
set PCNT $PAGE
}

set npage [expr $PCNT+1]
if {$npage < 10} {
  set tmp "0"
  append tmp $npage
  set npage $tmp
}

catch { exec ls $FAX.$npage } test
if { $test != "$FAX.$npage" } {
  set sof "0"
  nomore
  } else {
  set PAGE $npage
  makexbm
  onetime
  }
} 

proc prevpage {} {
global userhome FAX PAGE sof

if {[string range $PAGE 0 0] == "0"} {
set PCNT [string range $PAGE 1 1]
} else {
set PCNT $PAGE
}

set ppage [expr $PCNT-1]
if {$ppage < 10} {
  set tmp "0"
  append tmp $ppage
  set ppage $tmp
}

catch { exec ls $FAX.$ppage } test
if { $test != "$FAX.$ppage" } {
  set sof "1"
  nomore
  } else {
  set PAGE $ppage
  makexbm
  onetime
  }
} 

proc printfax {} {
global tkvoicedir userhome FAX PAGE PAGET printcmd printsel faxdpi

uplevel [list source [file join $tkvoicedir/TCL/tkvprintfax.tcl]]
}

# END PROCS Section

######################################################
# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoiceviewfax}
image create photo tkvoiceviewfax -file [file join $tkvoicedir/image/tkvoiceviewfax.gif]

label $w.gif.tkvoiceviewfax -image tkvoiceviewfax -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoiceviewfax -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right

#########################

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.print -text PRINT -command "printfax"
pack $w.buttons.print -side left -expand 1
button $w.buttons.onetime -text "1X" -command "onetime"
pack $w.buttons.onetime -side left -expand 1
button $w.buttons.twotime -text "2X"  -command "twotime"
pack $w.buttons.twotime -side left -expand 1
button $w.buttons.threetime -text "3X"  -command "threetime"
pack $w.buttons.threetime -side left -expand 1
button $w.buttons.prevpage -text "Prev Page" -command "prevpage"
pack $w.buttons.prevpage -side left -expand 1
set p $w.buttons.page
text $p -relief sunken -width 5 -height 1
pack $p -side left
button $w.buttons.nextpage -text "Next Page" -command "nextpage"
pack $w.buttons.nextpage -side left -expand 1
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.cancel -side left -expand 1

frame $w.fax
pack $w.fax -side top -fill both -expand yes

set c $w.fax.c
canvas $c -scrollregion {0i 0i 35i 45.5i} -width 8.8i -height 5.5i \
	-relief groove -borderwidth 2 \
	-xscrollcommand "$w.fax.hscroll set" \
	-yscrollcommand "$w.fax.vscroll set"
scrollbar $w.fax.vscroll -command "$c yview"
scrollbar $w.fax.hscroll -orient horiz -command "$c xview"

grid $c -in $w.fax \
    -row 0 -column 0 -rowspan 1 -columnspan 1 -sticky news
grid $w.fax.vscroll \
    -row 0 -column 1 -rowspan 1 -columnspan 1 -sticky news
grid $w.fax.hscroll \
    -row 1 -column 0 -rowspan 1 -columnspan 1 -sticky news
grid rowconfig    $w.fax 0 -weight 1 -minsize 0
grid columnconfig $w.fax 0 -weight 1 -minsize 0

onetime
